import {
  getBusinessConditionDatas,
  getAllTypeBusinessConditionDatas,
  getAllTypeBusinessConditionDetailByDay
} from "../../api/apiList";
import {calc_hb_str, calc_tb_str, conver_amont} from "../../utils/numUtil";
import moment from 'moment'
//天维度数据转换
export const getTrunOverDayDetail = async function (type, cur_day) {
  let pageData = new Object();
  pageData.head = await getHeadDay(type, cur_day)
  pageData.detail = await getDetailDay(type, cur_day)
  console.log("pageData:" + JSON.stringify(pageData))
  return pageData;

};
/**
 * @param cur_day
 */
export const getHeadDay = async function (type, cur_day) {
  let headData = new Object();
  let res = await reqSumData(cur_day);
  headData.营业额 = adapterSumDataDay(type, res);
  let transportData = await reqTransportData(cur_day)
  headData.汽运营业额 = initSumDataDay();
  headData.水运营业额 = initSumDataDay();
  headData.铁运营业额 = initSumDataDay();
  if (transportData[10]) {
    headData.汽运营业额 = adapterSumDataDay(type, transportData[10]);
  }
  if (transportData[30]) {
    headData.水运营业额 = adapterSumDataDay(type, transportData[30]);
  }
  if (transportData[20]) {
    headData.铁运营业额 = adapterSumDataDay(type, transportData[20]);
  }
  return headData;
};
//获取折线图明细
export const getDetailDay = async function (type, cur_day) {
  let transportDetail = await reqTransportDetailDayData(cur_day)
  return adapterDetailDataDay(type, transportDetail)
};

//获取汇总数据
export const reqSumData = async function (cur_day) {
  let res = await getBusinessConditionDatas(cur_day);
  let data = res.data
  return data;
}

//获取汇总数据
export const reqTransportData = async function (cur_day) {
  let res = await getAllTypeBusinessConditionDatas(cur_day);
  let data = res.data
  return data;
}

//获取明细数据数据
export const reqTransportDetailDayData = async function (cur_day) {
  let res = await getAllTypeBusinessConditionDetailByDay(moment(cur_day).format('YYYY-MM'));
  let data = res.data
  return data;
}


/**
 *日维度汇总
 * @param type yye:营业额、cb:成本、ml:毛利
 * @param data
 */
export const adapterSumDataDay = function (type, data) {
  let turnOver = new Object()
  let hb = new Array()
  if (type == 'yye') {
    turnOver.title = '营业额'
    turnOver.amount = conver_amont(data.cur_sell_settle_amount);
    //昨日环比
    if (data.pre_sell_settle_amount) {
      let yesterday = new Object()
      yesterday.title = '昨日'
      yesterday.amount = conver_amont(data.pre_sell_settle_amount);
      yesterday.rate = calc_hb_str(data.cur_sell_settle_amount, data.pre_sell_settle_amount);
      hb.push(yesterday)
    }
    //昨日环比
    if (data.pre_month_sell_settle_amount) {
      let premonth = new Object()
      premonth.title = '上月'
      premonth.amount = conver_amont(data.pre_month_sell_settle_amount);
      premonth.rate = calc_tb_str(data.cur_sell_settle_amount, data.pre_month_sell_settle_amount);
      hb.push(premonth)
    }
    turnOver.hb = hb;
  }
  if (type == 'cb') {
    turnOver.title = '成本'
    turnOver.amount = conver_amont(data.cur_buy_settle_amount);
    //昨日环比
    if (data.pre_buy_settle_amount) {
      let yesterday = new Object()
      yesterday.title = '昨日'
      yesterday.amount = conver_amont(data.pre_buy_settle_amount);
      yesterday.rate = calc_hb_str(data.cur_buy_settle_amount, data.pre_buy_settle_amount);
      hb.push(yesterday)
    }
    //昨日环比
    if (data.pre_month_buy_settle_amount) {
      let premonth = new Object()
      premonth.title = '上月'
      premonth.amount = conver_amont(data.pre_month_buy_settle_amount);
      premonth.rate = calc_tb_str(data.cur_buy_settle_amount, data.pre_month_buy_settle_amount);
      hb.push(premonth)
    }
    turnOver.hb = hb;
  }
  if (type == 'ml') {
    turnOver.title = '毛利'
    turnOver.amount = conver_amont(data.cur_gross_profit_amount);
    //昨日环比
    if (data.pre_gross_profit_amount) {
      let yesterday = new Object()
      yesterday.title = '昨日'
      yesterday.amount = conver_amont(data.pre_gross_profit_amount);
      yesterday.rate = calc_hb_str(data.cur_gross_profit_amount, data.pre_gross_profit_amount);
      hb.push(yesterday)
    }
    //昨日环比
    if (data.pre_month_gross_profit_amount) {
      let premonth = new Object()
      premonth.title = '上月'
      premonth.amount = conver_amont(data.pre_month_gross_profit_amount);
      premonth.rate = calc_tb_str(data.cur_gross_profit_amount, data.pre_month_gross_profit_amount);
      hb.push(premonth)
    }
    turnOver.hb = hb;
  }
  return turnOver;
}

/**
 * 初始化汇总数据
 * @returns {Object}
 */
export const initSumDataDay = function () {
  let turnOver = new Object()
  turnOver.title = '营业额'
  turnOver.amount = "0.0"
  let hb = new Array()
  let yesterday = new Object()
  yesterday.title = '昨日'
  yesterday.amount = "0.0"
  yesterday.rate = "0.0"
  hb.push(yesterday)
  yesterday = new Object()
  yesterday.title = '上月'
  yesterday.amount = "0.0"
  yesterday.rate = "0.0"
  hb.push(yesterday)
  turnOver.hb = hb
  return turnOver;

}

/**
 * 月维度汇总
 * @param type
 * @param data
 */
export const adapterSumDatamonth = function (type, data) {
  let turnOver = new Object()
  let hb = new Array()
  if (type == 'yye') {
    turnOver.title = '营业额'
    turnOver.amount = conver_amont(data.cur_month_buy_settle_amount);
    //昨日环比
    if (data.pre_month_sell_settle_amount) {
      let yesterday = new Object()
      yesterday.title = '上月'
      yesterday.amount = conver_amont(data.pre_month_sell_settle_amount);
      yesterday.rate = calc_hb_str(data.cur_month_buy_settle_amount, data.pre_month_sell_settle_amount);
      hb.push(yesterday)
    }
    //昨日环比
    if (data.pre_year_sell_settle_amount) {
      let premonth = new Object()
      premonth.title = '去年'
      premonth.amount = conver_amont(data.pre_year_sell_settle_amount);
      premonth.rate = calc_tb_str(data.cur_sell_settle_amount, data.pre_year_sell_settle_amount);
      hb.push(premonth)
    }
    turnOver.hb = hb;
  }
  if (type == 'cb') {
    turnOver.title = '成本'
    turnOver.amount = conver_amont(data.cur_month_buy_settle_amount);
    //上月环比
    if (data.pre_month_buy_settle_amount) {
      let yesterday = new Object()
      yesterday.title = '上月'
      yesterday.amount = conver_amont(data.pre_month_buy_settle_amount);
      yesterday.rate = calc_hb_str(data.cur_month_buy_settle_amount, data.pre_month_buy_settle_amount);
      hb.push(yesterday)
    }
    //去年环比
    if (data.pre_year_buy_settle_amount) {
      let premonth = new Object()
      premonth.title = '去年'
      premonth.amount = conver_amont(data.pre_year_buy_settle_amount);
      premonth.rate = calc_tb_str(data.cur_month_buy_settle_amount, data.pre_year_buy_settle_amount);
      hb.push(premonth)
    }
    turnOver.hb = hb;
  }
  if (type == 'ml') {
    turnOver.title = '毛利'
    turnOver.amount = conver_amont(data.cur_month_gross_profit_amount);
    //昨日环比
    if (data.pre_month_gross_profit_amount) {
      let yesterday = new Object()
      yesterday.title = '上月'
      yesterday.amount = conver_amont(data.pre_month_gross_profit_amount);
      yesterday.rate = calc_hb_str(data.cur_month_gross_profit_amount, data.pre_month_gross_profit_amount);
      hb.push(yesterday)
    }
    //昨日环比
    if (data.pre_year_gross_profit_amount) {
      let premonth = new Object()
      premonth.title = '去年'
      premonth.amount = conver_amont(data.pre_year_gross_profit_amount);
      premonth.rate = calc_tb_str(data.cur_month_gross_profit_amount, data.pre_year_gross_profit_amount);
      hb.push(premonth)
    }
    turnOver.hb = hb;
  }
}

/**
 * 月维度汇总
 * @param type
 * @param data
 */
export const adapterSumDataYear = function (type, data) {
  let turnOver = new Object()
  let hb = new Array()
  if (type == 'yye') {
    turnOver.title = '营业额'
    turnOver.amount = conver_amont(data.cur_year_sell_settle_amount);
    //昨日环比
    if (data.pre_year_sell_settle_amount) {
      let yesterday = new Object()
      yesterday.title = '去年'
      yesterday.amount = conver_amont(data.pre_year_sell_settle_amount);
      yesterday.rate = calc_hb_str(data.cur_year_sell_settle_amount, data.pre_year_sell_settle_amount);
      hb.push(yesterday)
    }
    turnOver.hb = hb;
  }
  if (type == 'cb') {
    turnOver.title = '成本'
    turnOver.amount = conver_amont(data.cur_year_buy_settle_amount);
    //上月环比
    if (data.pre_year_buy_settle_amount) {
      let yesterday = new Object()
      yesterday.title = '去年'
      yesterday.amount = conver_amont(data.pre_year_buy_settle_amount);
      yesterday.rate = calc_hb_str(data.cur_year_buy_settle_amount, data.pre_year_buy_settle_amount);
      hb.push(yesterday)
    }
    turnOver.hb = hb;
  }
  if (type == 'ml') {
    turnOver.title = '毛利'
    turnOver.amount = conver_amont(data.cur_year_gross_profit_amount);
    //昨日环比
    if (data.pre_year_gross_profit_amount) {
      let yesterday = new Object()
      yesterday.title = '去年'
      yesterday.amount = conver_amont(data.pre_year_gross_profit_amount);
      yesterday.rate = calc_hb_str(data.cur_year_gross_profit_amount, data.pre_year_gross_profit_amount);
      hb.push(yesterday)
    }
    turnOver.hb = hb;
  }
}


/**
 * 详细数据匹配
 * @param type
 * @param data
 * @returns {any[]}
 */
export const adapterDetailDataDay = function (type, data) {
  let list = new Array()
  let detail = null
  for (let key in data) {
    detail = detailConver(type, data[key])
    detail.date = moment(key).format('MM月DD日');
    list.push(detail);
  }
  return list;
}

/**
 * 详细数据转换
 * @param type
 * @param detailList
 * @returns {Object}
 */
export const detailConver = function (type, detailList) {
  let detail = initDetail();
  console.log(typeof detailList)
  for (let det in detailList) {
    let data = detailList[det]
    //初始化
    if (type == 'yye') {
      if (data.cur_transport_type == '10') {
        detail['汽运(元)'] = data.cur_sell_settle_amount;
      }
      if (data.cur_transport_type == '30') {
        detail['水运(元)'] = data.cur_sell_settle_amount
      }
      if (data.cur_transport_type == '20') {
        detail['铁运(元)'] = data.cur_sell_settle_amount
      }
    }
    if (type == 'cb') {
      if (data.cur_transport_type == '10') {
        detail['汽运(元)'] = data.cur_buy_settle_amount
      }
      if (data.cur_transport_type == '30') {
        detail['水运(元)'] = data.cur_buy_settle_amount
      }
      if (data.cur_transport_type == '20') {
        detail['铁运(元)'] = data.cur_buy_settle_amount
      }
    }
    if (type == 'ml') {
      if (data.cur_transport_type == '10') {
        detail['汽运(元)'] = data.cur_gross_profit_amount
      }
      if (data.cur_transport_type == '30') {
        detail['水运(元)'] = data.cur_gross_profit_amount
      }
      if (data.cur_transport_type == '20') {
        detail['铁运(元)'] = data.cur_gross_profit_amount
      }
    }
  }
  return detail;
}
/**
 * @returns {{}}
 */
export const initDetail = function () {
  let detail = {};
  detail['汽运(元)'] = 0
  detail['水运(元)'] = 0
  detail['铁运(元)'] = 0
  return detail;
}

